@@ -83,6 +83,20 @@ def post_v2(url, data):
         raise CnvrgError(messages)
     return resp
 
+@suppress_exception
+def put_v2(url, data):
+    urllib3.disable_warnings()
+    verify_logged_in()
+    get_url = url_join(credentials.api_url, "v2", url)
+    resp = requests.put(url=get_url, json=data, headers={"Auth-Token": credentials.token}, verify=False)
+    if resp.status_code == 404:
+        raise CnvrgError('Not Found')
+    if resp.status_code != 200:
+        messages = []
+        for m in resp.json().values():
+            messages.append(m) if isinstance(m, str) else messages.append(m[0])
+        raise CnvrgError(messages)
+    return resp
 
 @suppress_exception
 def send_file(url, data=None, files=None):
