@@ -3,7 +3,7 @@ from keras.callbacks import Callback
 from cnvrg.modules.experiment import Experiment
 class CnvrgKerasCallback(Callback):
     def __init__(self):
-        self.experiment = Experiment("omeriz/gpuish/dbR-WGXHqwEzo3CkWpsv")
+        self.experiment = Experiment()
         super(CnvrgKerasCallback, self).__init__()
 
     def on_epoch_begin(self, epoch=None, logs=None):
