@@ -121,10 +121,12 @@ class Endpoint(CnvrgJob):
     def update_model(self, title=None, kind=None, input_file=None, file_name=None, function_name=None,
                      kafka_brokers=None, kafka_input_topics=None, kafka_output_topics=None, templates_names=None,
                      image_slug=None, commit=None, prep_file=None, prep_function=None, git_commit=None,
-                     git_branch=None):
+                     git_branch=None, last_deployment_commits=False):
         self._refresh_data()
         if self.data["last_deployment"] == None or self.data["status"] == "stopped":
             raise CnvrgError("Can't find last deployment")
+        if self.data["deployments"][-1]["is_update"]:
+            raise CnvrgError("Can't update an endpoint that is currently updating")
         if templates_names and not isinstance(templates_names, list):
             raise CnvrgError("templates_names must be in a list")
         if kafka_brokers and not isinstance(kafka_brokers, list):
@@ -134,6 +136,10 @@ class Endpoint(CnvrgJob):
         if kafka_output_topics and not isinstance(kafka_output_topics, list):
             raise CnvrgError("kafka_output_topics must be in a list")
 
+        if last_deployment_commits:
+            git_commit = self.data["last_deployment"]["git_commit"]
+            commit = self.data["last_deployment"]["commit"]
+
         old_kind = self.data["kind"]
         if kind is None:
             if old_kind == "webserver":
