@@ -2,6 +2,7 @@ import os
 import time
 import json
 import types
+from croniter import croniter
 import numpy as np
 
 from enum import Enum
@@ -52,6 +53,7 @@ class Experiment(CnvrgJob, ChartsMixin):
         if isinstance(project, str):
             project = Project(project)
         project = project or Project()
+        kwargs["clean_experiment"] = True
         resp = apis_helper.post(url_join(project.get_base_url(), 'experiments', 'local'),
                                 data={"commit": project.get_current_commit(), **kwargs, **env_helper.get_origin_job()})
         e = resp.get("experiment")
@@ -107,6 +109,10 @@ class Experiment(CnvrgJob, ChartsMixin):
             "job": self.job_slug,
             "in_exp": "true"
         }
+
+        if self.__data["compute"] == "local":
+            payload["local"] = "true"
+
         if self.project.is_git():
             payload["output_dir"] = output_dir
             if git_diff:
@@ -114,13 +120,31 @@ class Experiment(CnvrgJob, ChartsMixin):
 
         self.project.sync(**payload)
 
+    def log_images(self, files: list, target=None):
+        try:
+            filters = ['image']
+            payload = {
+                "job_type": "Experiment",
+                "workflow_slug": self.job_slug,
+                "source": 'sdk'
+            }
+            self.project.put_files(files, message="Log Images Commit", payload=payload, prefix=target, filters=filters, tag_images=True)
+        except APINotFound:  # To support old server version
+            payload = {
+                "job_type": "Experiment",
+                "job_slug": self.job_slug,
+                "in_exp": "true",
+                "files": files,
+            }
+            self.project.sync(**payload)
+
     def log_artifacts(self, files: list, target=None):
         try:
             payload = {
                 "job_type": "Experiment",
-                "job_slug": self.job_slug
+                "workflow_slug": self.job_slug
             }
-            self.project.put_files(files, message="Log Artifacts Commit", payload=payload, prefix=target)
+            self.project.put_files(files, message="Log Artifacts Commit", payload=payload, prefix=target, tag_images=True)
         except APINotFound:  # To support old server version
             payload = {
                 "job_type": "Experiment",
@@ -200,6 +224,9 @@ class Experiment(CnvrgJob, ChartsMixin):
         function_command = None
         project = project or Project()
 
+        if recurring and not croniter.is_valid(recurring):
+            raise UserError("Cron is not valid")
+
         if project.git:
             git_commit = git_commit or project.get_git_commit()
             output_dir = output_dir or "output"
@@ -294,7 +321,7 @@ class Experiment(CnvrgJob, ChartsMixin):
                 **kwargs
             )
             if len(e.get("experiments")) == 1:
-                exp = Experiment(e.get("experiments")[0], owner=project.owner+"/"+project.slug)
+                exp = Experiment(e.get("experiments")[0], owner=project.owner)
                 exp.notify_running()
                 exp.set_as_default()
                 return exp
@@ -375,11 +402,15 @@ class Experiment(CnvrgJob, ChartsMixin):
             for index, item in enumerate(Ys):
                 if isinstance(item, np.generic):
                     Ys[index] = item.item()
+                if isinstance(item, np.ndarray):
+                    Ys[index] = item.tolist()
 
         if isinstance(Xs, list):
             for index, item in enumerate(Xs):
                 if isinstance(item, np.generic):
                     Xs[index] = item.item()
+                if isinstance(item, np.ndarray):
+                    Xs[index] = item.tolist()
 
         # Support for regular types
         if not isinstance(Ys, list):
@@ -491,7 +522,7 @@ class Experiment(CnvrgJob, ChartsMixin):
         apis_helper.post(url_join(self._base_url(), 'tags'), data={"tag": tag_data})
 
     @suppress_exception
-    def finish(self, exit_status=None):
+    def finish(self, exit_status=0):
         apis_helper.post(url_join(self._base_url(), 'finish'), data={"exit_status": exit_status})
 
     def href(self):
